/*
 * Copyright (c) 2019 Meltytech, LLC
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

import QtQuick 2.0
import QtQuick.Controls 1.1
import QtQuick.Layouts 1.1
import Shotcut.Controls 1.0

KeyframableFilter {
    property string borderwidth: '0'
//    property string transparency: '1'
    property double borderwidthDefault: 0.259
    

    keyframableParameters: [borderwidth]
    startValues: [0.5]
    middleValues: [borderwidthDefault]
    endValues: [0.5]

    width: 350
    height: 100

    Component.onCompleted: {
        if (filter.isNew) {
            filter.set(borderwidth, borderwidthDefault)
//            filter.set(transparency, 0)
            filter.savePreset(preset.parameters)
        }
        setControls()
    }

    function setControls() {
        var position = getPosition()
        blockUpdate = true
        borderwidthSlider.value = filter.getDouble(borderwidth, position) * borderwidthSlider.maximumValue
        blockUpdate = false
        enableControls(isSimpleKeyframesActive())
    }

    function enableControls(enabled) {
        borderwidthSlider.enabled = enabled
    }

    function updateSimpleKeyframes() {
        updateFilter(borderwidth, borderwidthSlider.value / borderwidthSlider.maximumValue, borderKeyframesButton)
        
    }

    GridLayout {
        anchors.fill: parent
        anchors.margins: 8
        columns: 4

        Label {
            text: qsTr('Preset')
            Layout.alignment: Qt.AlignRight
        }
        Preset {
            id: preset
            parameters: [borderwidth, transparency]
            Layout.columnSpan: 3
            onBeforePresetLoaded: {
                filter.resetProperty(borderwidth)
//                filter.resetProperty(transparency)
            }
            onPresetSelected: {
                setControls()
                initializeSimpleKeyframes()
            }
        }

        Label {
            text: qsTr('Border Width')
            Layout.alignment: Qt.AlignRight
        }
        SliderSpinner {
            id: borderwidthSlider
            minimumValue: 0
            maximumValue: profile.height
            stepSize: 1
            decimals: 0
            suffix: ' px'
            onValueChanged: updateFilter(borderwidth, borderwidthSlider.value / borderwidthSlider.maximumValue, borderKeyframesButton, getPosition())
        }
        UndoButton {
            onClicked: borderwidthSlider.value = borderwidthDefault * borderwidthSlider.maximumValue
        }
        KeyframesButton {
            id: borderKeyframesButton
            checked: filter.animateIn <= 0 && filter.animateOut <= 0 && filter.keyframeCount(borderwidth) > 0
            onToggled: {
                enableControls(true)
                toggleKeyframes(checked, borderwidth, borderwidthSlider.value / borderwidthSlider.maximumValue)
            }
        }

//        Label {}
//        CheckBox {
//            id: transparencyCheckBox
//            text: qsTr('Transparency')
//            Layout.columnSpan: 2
//            checked: filter.get('transparency') === '1'
//            property bool isReady: false
//            Component.onCompleted: isReady = true
//            onClicked: {
//                if (isReady)
//                    filter.set('transparency', checked)
//            }
//        }

        Item {
            Layout.fillHeight: true
        }
    }

    Connections {
        target: filter
        onInChanged: updateSimpleKeyframes()
        onOutChanged: updateSimpleKeyframes()
        onAnimateInChanged: updateSimpleKeyframes()
        onAnimateOutChanged: updateSimpleKeyframes()
    }

    Connections {
        target: producer
        onPositionChanged: setControls()
    }
}
